@@ -1,10 +1,9 @@
 from __future__ import annotations
 
-import re
-import token as _token
-import tokenize as _tokenize
-from dataclasses import dataclass, field
+import dataclasses
+from dataclasses import dataclass
 from enum import Enum, auto
+from typing import List, Optional, Union
 
 
 class AST:
@@ -28,19 +27,19 @@ class Module(Node):
 @dataclass
 class Type(Node):
     name: str
-    value: Node
+    value: Union[Sum, Product]
 
 
 @dataclass
 class Sum(Node):
     types: List[Constructor]
-    attributes: List[Field] = field(default_factory=list)
+    attributes: List[Field] = dataclasses.field(default_factory=list)
 
 
 @dataclass
 class Product(Node):
     fields: List[Field]
-    attributes: List[Field] = field(default_factory=list)
+    attributes: List[Field] = dataclasses.field(default_factory=list)
 
 
 @dataclass
@@ -62,15 +61,3 @@ class Field(Leaf):
     kind: str
     name: str
     qualifier: Optional[FieldQualifier] = None
-
-
-def add_comment_type(prefix):
-    _tokenize.EXACT_TOKEN_TYPES[prefix] = _token.COMMENT
-    _tokenize.PseudoToken = _tokenize.Whitespace + _tokenize.group(
-        re.escape(prefix),
-        _tokenize.PseudoExtras,
-        _tokenize.Number,
-        _tokenize.Funny,
-        _tokenize.ContStr,
-        _tokenize.Name,
-    )
